@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.012-4-g2421602
+package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.013-6-g5690f92
 # ABSTRACT: Compare data and files at different phases of the distribution build process
 # KEYWORDS: plugin distribution configuration phase verification validation
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Moose;
 with
@@ -33,7 +33,7 @@ sub _search_all_files
 
     for my $filename (keys %all_files)
     {
-        foreach my $index (0.. $#{$all_files{$filename}})
+        foreach my $index (0 .. $#{$all_files{$filename}})
         {
             return ($filename, $index) if $all_files{$filename}[$index]{object} == $file;
         }
@@ -76,7 +76,18 @@ sub BUILD
 }
 
 # no reason to include configs - this plugin does not alter the build output
-# around dump_config => sub { ... };
+around dump_config => sub
+{
+    my ($orig, $self) = @_;
+    my $config = $self->$orig;
+
+    my $data = {
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
+    };
+    $config->{+__PACKAGE__} = $data if keys %$data;
+
+    return $config;
+};
 
 sub before_build
 {
@@ -94,7 +105,7 @@ sub gather_files
     my $zilla = $self->zilla;
     my $meta = find_meta($zilla);
 
-    foreach my $attr_name (qw(name version release_status abstract main_module authors distmeta))
+    foreach my $attr_name (qw(name version release_status abstract main_module authors distmeta _share_dir_map))
     {
         next if exists $zilla_constructor_args{$attr_name};
         my $attr = $meta->find_attribute_by_name($attr_name);
@@ -342,7 +353,7 @@ Dist::Zilla::Plugin::VerifyPhases - Compare data and files at different phases o
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -395,6 +406,10 @@ authors
 
 metadata
 
+=item *
+
+_share_dir_map
+
 =back
 
 Running at the end of the C<-EncodingProvider> phase, it forces all encodings
@@ -426,14 +441,6 @@ early, resulting in incomplete or missing data).
 
 =for Pod::Coverage BUILD before_build gather_files set_file_encodings prune_files munge_files after_build
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-Author-ETHER>
-(or L<bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org|mailto:bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -448,6 +455,19 @@ L<Dist::Zilla::App::Command::dumpphases>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-VerifyPhases>
+(or L<bug-Dist-Zilla-Plugin-VerifyPhases@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-VerifyPhases@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
